@@ -1,5 +1,5 @@
 
-# This file is part of CovidPy v0.0.3.
+# This file is part of CovidPy v0.0.5.
 #
 # The project has been distributed in the hope it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -8,6 +8,6 @@
 # You can use it and/or modify it under the terms of the GNU General Public License v3.0 or later.
 # You should have received a copy of the GNU General Public License along with the project.
 from .lib import CovidPy
-from .types import QRCode
+from .types import QRCode, VerifyResult
 from .verifier import DCCVerifier
 from .errors import InvalidDCC
\ No newline at end of file
